@@ -2,11 +2,17 @@ use strict;
 use warnings;
 
 package Footprintless::Resource::Provider;
-$Footprintless::Resource::Provider::VERSION = '1.09';
+$Footprintless::Resource::Provider::VERSION = '1.10';
 # ABSTRACT: A contract for providing resources to the resource manager
 # PODNAME: Footprintless::Resource::Provider
 
 use Carp;
+use Footprintless::Util qw(
+    temp_file
+);
+use Log::Any;
+
+my $logger = Log::Any->get_logger();
 
 sub new {
     return bless( {}, shift )->_init(@_);
@@ -56,7 +62,7 @@ Footprintless::Resource::Provider - A contract for providing resources to the re
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 DESCRIPTION
 
