@@ -2,17 +2,22 @@ use strict;
 use warnings;
 
 package Footprintless::Resource::UrlProvider;
-$Footprintless::Resource::UrlProvider::VERSION = '1.09';
+$Footprintless::Resource::UrlProvider::VERSION = '1.10';
 # ABSTRACT: A resource provider for resources retrieved by URL
 # PODNAME: Footprintless::Resource::UrlProvider
 
 use parent qw(Footprintless::Resource::Provider);
 
 use Carp;
-use File::Temp;
 use Footprintless::Resource::Url;
+use Footprintless::Util qw(
+    temp_file
+);
+use Log::Any;
 use URI;
 
+my $logger = Log::Any->get_logger();
+
 sub _download {
     my ( $self, $resource, %options ) = @_;
 
@@ -25,7 +30,13 @@ sub _download {
         }
     }
     else {
-        $file = Footprintless::Resource::UrlProvider::DownloadedFile->new();
+        my @suffix;
+        if ( $resource->get_url() =~ /.*(\.\S*)$/ ) {
+            $logger->tracef( 'preserving extension [%s] for resource %s', $1, $resource );
+            push( @suffix, suffix => $1 );
+        }
+
+        $file = temp_file(@suffix);
     }
 
     my $response = $self->{agent}->get( $resource->get_uri(), ':content_file' => "$file" );
@@ -59,27 +70,6 @@ sub supports {
     return 1;
 }
 
-package Footprintless::Resource::UrlProvider::DownloadedFile;
-$Footprintless::Resource::UrlProvider::DownloadedFile::VERSION = '1.09';
-# Wraps a temp file to hold a reference so as to keep the destructor from
-# getting called.  It will provide the filename when used as a string.
-
-use overload q{""} => 'filename', fallback => 1;
-
-sub new {
-    my $self = bless( {}, shift );
-    my $file = File::Temp->new();
-
-    $self->{handle} = $file;
-    $self->{name}   = $file->filename();
-
-    return $self;
-}
-
-sub filename {
-    return $_[0]->{name};
-}
-
 1;
 
 __END__
@@ -92,7 +82,7 @@ Footprintless::Resource::UrlProvider - A resource provider for resources retriev
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 CONSTRUCTORS
 
