@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Footprintless::Util;
-$Footprintless::Util::VERSION = '1.09';
+$Footprintless::Util::VERSION = '1.10';
 # ABSTRACT: A utility method package for common functionality in Footprintless
 # PODNAME: Footprintless::Util
 
@@ -29,6 +29,7 @@ our @EXPORT_OK = qw(
 );
 
 my $logger = Log::Any->get_logger();
+my $extract_impl;
 
 sub agent {
     my (%options) = @_;
@@ -112,28 +113,18 @@ sub extract {
     my ( $archive, %options ) = @_;
 
     my @to = $options{to} ? ( to => $options{to} ) : ();
-    my @type = ();
+    my @type_option = ();
     if ( $options{type} ) {
-        push( @type, type => $options{type} );
+        push( @type_option, type => $options{type} );
     }
     elsif ( $archive =~ /\.war|\.jar|\.ear|\.twbx$/ ) {
 
         # other known zip type extensions
-        push( @type, type => 'zip' );
+        push( @type_option, type => 'zip' );
     }
 
-    if ( require Archive::Extract::Libarchive ) {
-        Archive::Extract::Libarchive->new( archive => $archive, @type )->extract(@to)
-            || croak("unable to extract $archive: $!");
-    }
-    elsif ( require Archive::Extract ) {
-        Archive::Extract->new( archive => $archive, @type )->extract(@to)
-            || croak("unable to extract $archive: $!");
-    }
-    else {
-        # todo: consider binary commands like unzip and tar
-        croak("extract requires either Archive::Extract::Libarchive or Archive::Extract");
-    }
+    return _new_extract( archive => $archive, @type_option )->extract(@to)
+        || croak("unable to extract $archive: $!");
 }
 
 sub factory {
@@ -167,6 +158,29 @@ sub invalid_entity {
     );
 }
 
+sub _new_extract {
+    my (@args) = @_;
+
+    unless ($extract_impl) {
+        eval {
+            require Archive::Extract::Libarchive;
+            $extract_impl = 'Archive::Extract::Libarchive';
+        };
+    }
+    unless ($extract_impl) {
+        eval {
+            require Archive::Extract;
+            $extract_impl = 'Archive::Extract';
+        };
+    }
+    unless ($extract_impl) {
+        require Footprintless::Extract;
+        $extract_impl = 'Footprintless::Extract';
+    }
+
+    return $extract_impl->new(@args);
+}
+
 sub rebase {
     my ( $path, $rebase ) = @_;
 
@@ -227,9 +241,14 @@ sub temp_dir {
 }
 
 sub temp_file {
+    my (%options) = @_;
     require File::Temp;
     File::Temp->safe_level( File::Temp::HIGH() );
-    my $temp = File::Temp->new( 'fpl_XXXXXXXX', TMPDIR => 1 );
+    my $temp = File::Temp->new(
+        'fpl_XXXXXXXX',
+        TMPDIR => 1,
+        ( $options{suffix} ? ( SUFFIX => $options{suffix} ) : () )
+    );
     if ( !chmod( 0600, $temp ) ) {
         croak("unable to create secure temp file");
     }
@@ -248,7 +267,7 @@ Footprintless::Util - A utility method package for common functionality in Footp
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
 =head1 SYNOPSIS
 
